# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_administration_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__pb2
from ....protocol.v30 import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from . import sequencer_initialization_snapshot_pb2 as com_dot_digitalasset_dot_canton_dot_sequencer_dot_admin_dot_v30_dot_sequencer__initialization__snapshot__pb2
from ....topology.admin.v30 import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__ext__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRcom/digitalasset/canton/sequencer/admin/v30/sequencer_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x35\x63om/digitalasset/canton/protocol/v30/sequencing.proto\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1aScom/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_snapshot.proto\x1a=com/digitalasset/canton/topology/admin/v30/topology_ext.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa4\x03\n\x1aTrafficControlStateRequest\x12\x18\n\x07members\x18\x01 \x03(\tR\x07members\x12)\n\x0f\x65xact_timestamp\x18\x02 \x01(\x04H\x00R\x0e\x65xactTimestamp\x12\x8a\x01\n\x12relative_timestamp\x18\x03 \x01(\x0e\x32Y.com.digitalasset.canton.sequencer.admin.v30.TrafficControlStateRequest.RelativeTimestampH\x00R\x11relativeTimestamp\"\x9d\x01\n\x11RelativeTimestamp\x12.\n*RELATIVE_TIMESTAMP_LATEST_SAFE_UNSPECIFIED\x10\x00\x12-\n)RELATIVE_TIMESTAMP_LAST_UPDATE_PER_MEMBER\x10\x01\x12)\n%RELATIVE_TIMESTAMP_LATEST_APPROXIMATE\x10\x02\x42\x14\n\x12timestamp_selector\"\x98\x02\n\x1bTrafficControlStateResponse\x12\x82\x01\n\x0etraffic_states\x18\x01 \x03(\x0b\x32[.com.digitalasset.canton.sequencer.admin.v30.TrafficControlStateResponse.TrafficStatesEntryR\rtrafficStates\x1at\n\x12TrafficStatesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.TrafficStateR\x05value:\x02\x38\x01\"\x84\x01\n\x1aSetTrafficPurchasedRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12\x36\n\x17total_traffic_purchased\x18\x03 \x01(\x03R\x15totalTrafficPurchased\"s\n\x1bSetTrafficPurchasedResponse\x12T\n\x18max_sequencing_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x16maxSequencingTimestamp\"K\n\x0fSnapshotRequest\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x94\x04\n\x10SnapshotResponse\x12\x61\n\x07success\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.admin.v30.SnapshotResponse.SuccessH\x00R\x07success\x12\x61\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.admin.v30.SnapshotResponse.FailureH\x00R\x07\x66\x61ilure\x12}\n\x11versioned_success\x18\x03 \x01(\x0b\x32N.com.digitalasset.canton.sequencer.admin.v30.SnapshotResponse.VersionedSuccessH\x00R\x10versionedSuccess\x1a_\n\x07Success\x12T\n\x05state\x18\x01 \x01(\x0b\x32>.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshotR\x05state\x1a!\n\x07\x46\x61ilure\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x1a.\n\x10VersionedSuccess\x12\x1a\n\x08snapshot\x18\x01 \x01(\x0cR\x08snapshotB\x07\n\x05value\"\x86\x01\n\x16OnboardingStateRequest\x12%\n\rsequencer_uid\x18\x01 \x01(\tH\x00R\x0csequencerUid\x12:\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\ttimestampB\t\n\x07request\"^\n\x17OnboardingStateResponse\x12\x43\n\x1eonboarding_state_for_sequencer\x18\x01 \x01(\x0cR\x1bonboardingStateForSequencer\"\xf3\x02\n\x1bOnboardingStateForSequencer\x12m\n\x11topology_snapshot\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x10topologySnapshot\x12v\n\x18static_domain_parameters\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v30.StaticDomainParametersR\x16staticDomainParameters\x12m\n\x12sequencer_snapshot\x18\x03 \x01(\x0b\x32>.com.digitalasset.canton.sequencer.admin.v30.SequencerSnapshotR\x11sequencerSnapshot\"\x16\n\x14PruningStatusRequest\"\x83\x01\n\x15PruningStatusResponse\x12j\n\x0epruning_status\x18\x01 \x01(\x0b\x32\x43.com.digitalasset.canton.sequencer.admin.v30.SequencerPruningStatusR\rpruningStatus\".\n\x14\x44isableMemberRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\"\x17\n\x15\x44isableMemberResponse2\xd3\x07\n\x1eSequencerAdministrationService\x12\x96\x01\n\rPruningStatus\x12\x41.com.digitalasset.canton.sequencer.admin.v30.PruningStatusRequest\x1a\x42.com.digitalasset.canton.sequencer.admin.v30.PruningStatusResponse\x12\xa8\x01\n\x13TrafficControlState\x12G.com.digitalasset.canton.sequencer.admin.v30.TrafficControlStateRequest\x1aH.com.digitalasset.canton.sequencer.admin.v30.TrafficControlStateResponse\x12\xa8\x01\n\x13SetTrafficPurchased\x12G.com.digitalasset.canton.sequencer.admin.v30.SetTrafficPurchasedRequest\x1aH.com.digitalasset.canton.sequencer.admin.v30.SetTrafficPurchasedResponse\x12\x87\x01\n\x08Snapshot\x12<.com.digitalasset.canton.sequencer.admin.v30.SnapshotRequest\x1a=.com.digitalasset.canton.sequencer.admin.v30.SnapshotResponse\x12\x9e\x01\n\x0fOnboardingState\x12\x43.com.digitalasset.canton.sequencer.admin.v30.OnboardingStateRequest\x1a\x44.com.digitalasset.canton.sequencer.admin.v30.OnboardingStateResponse0\x01\x12\x96\x01\n\rDisableMember\x12\x41.com.digitalasset.canton.sequencer.admin.v30.DisableMemberRequest\x1a\x42.com.digitalasset.canton.sequencer.admin.v30.DisableMemberResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_TRAFFICCONTROLSTATERESPONSE_TRAFFICSTATESENTRY']._loaded_options = None
  _globals['_TRAFFICCONTROLSTATERESPONSE_TRAFFICSTATESENTRY']._serialized_options = b'8\001'
  _globals['_TRAFFICCONTROLSTATEREQUEST']._serialized_start=439
  _globals['_TRAFFICCONTROLSTATEREQUEST']._serialized_end=859
  _globals['_TRAFFICCONTROLSTATEREQUEST_RELATIVETIMESTAMP']._serialized_start=680
  _globals['_TRAFFICCONTROLSTATEREQUEST_RELATIVETIMESTAMP']._serialized_end=837
  _globals['_TRAFFICCONTROLSTATERESPONSE']._serialized_start=862
  _globals['_TRAFFICCONTROLSTATERESPONSE']._serialized_end=1142
  _globals['_TRAFFICCONTROLSTATERESPONSE_TRAFFICSTATESENTRY']._serialized_start=1026
  _globals['_TRAFFICCONTROLSTATERESPONSE_TRAFFICSTATESENTRY']._serialized_end=1142
  _globals['_SETTRAFFICPURCHASEDREQUEST']._serialized_start=1145
  _globals['_SETTRAFFICPURCHASEDREQUEST']._serialized_end=1277
  _globals['_SETTRAFFICPURCHASEDRESPONSE']._serialized_start=1279
  _globals['_SETTRAFFICPURCHASEDRESPONSE']._serialized_end=1394
  _globals['_SNAPSHOTREQUEST']._serialized_start=1396
  _globals['_SNAPSHOTREQUEST']._serialized_end=1471
  _globals['_SNAPSHOTRESPONSE']._serialized_start=1474
  _globals['_SNAPSHOTRESPONSE']._serialized_end=2006
  _globals['_SNAPSHOTRESPONSE_SUCCESS']._serialized_start=1819
  _globals['_SNAPSHOTRESPONSE_SUCCESS']._serialized_end=1914
  _globals['_SNAPSHOTRESPONSE_FAILURE']._serialized_start=1916
  _globals['_SNAPSHOTRESPONSE_FAILURE']._serialized_end=1949
  _globals['_SNAPSHOTRESPONSE_VERSIONEDSUCCESS']._serialized_start=1951
  _globals['_SNAPSHOTRESPONSE_VERSIONEDSUCCESS']._serialized_end=1997
  _globals['_ONBOARDINGSTATEREQUEST']._serialized_start=2009
  _globals['_ONBOARDINGSTATEREQUEST']._serialized_end=2143
  _globals['_ONBOARDINGSTATERESPONSE']._serialized_start=2145
  _globals['_ONBOARDINGSTATERESPONSE']._serialized_end=2239
  _globals['_ONBOARDINGSTATEFORSEQUENCER']._serialized_start=2242
  _globals['_ONBOARDINGSTATEFORSEQUENCER']._serialized_end=2613
  _globals['_PRUNINGSTATUSREQUEST']._serialized_start=2615
  _globals['_PRUNINGSTATUSREQUEST']._serialized_end=2637
  _globals['_PRUNINGSTATUSRESPONSE']._serialized_start=2640
  _globals['_PRUNINGSTATUSRESPONSE']._serialized_end=2771
  _globals['_DISABLEMEMBERREQUEST']._serialized_start=2773
  _globals['_DISABLEMEMBERREQUEST']._serialized_end=2819
  _globals['_DISABLEMEMBERRESPONSE']._serialized_start=2821
  _globals['_DISABLEMEMBERRESPONSE']._serialized_end=2844
  _globals['_SEQUENCERADMINISTRATIONSERVICE']._serialized_start=2847
  _globals['_SEQUENCERADMINISTRATIONSERVICE']._serialized_end=3826
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/domain_connectivity.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/domain_connectivity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...time.v30 import time_tracker_config_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_time_dot_v30_dot_time__tracker__config__pb2
from ...domain.v30 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_domain_dot_v30_dot_sequencer__connection__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/digitalasset/canton/admin/participant/v30/domain_connectivity.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a@com/digitalasset/canton/admin/time/v30/time_tracker_config.proto\x1a\x43\x63om/digitalasset/canton/admin/domain/v30/sequencer_connection.proto\x1a\x1egoogle/protobuf/duration.proto\"\xc7\x04\n\x16\x44omainConnectionConfig\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12s\n\x15sequencer_connections\x18\x02 \x01(\x0b\x32>.com.digitalasset.canton.admin.domain.v30.SequencerConnectionsR\x14sequencerConnections\x12%\n\x0emanual_connect\x18\x03 \x01(\x08R\rmanualConnect\x12\x1b\n\tdomain_id\x18\x04 \x01(\tR\x08\x64omainId\x12\x1a\n\x08priority\x18\x05 \x01(\x05R\x08priority\x12I\n\x13initial_retry_delay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11initialRetryDelay\x12\x41\n\x0fmax_retry_delay\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rmaxRetryDelay\x12\x62\n\x0ctime_tracker\x18\x08 \x01(\x0b\x32?.com.digitalasset.canton.admin.time.v30.DomainTimeTrackerConfigR\x0btimeTracker\x12\x43\n\x1einitialize_from_trusted_domain\x18\n \x01(\x08R\x1binitializeFromTrustedDomain\"B\n\x17ReconnectDomainsRequest\x12\'\n\x0fignore_failures\x18\x01 \x01(\x08R\x0eignoreFailures\"\x1a\n\x18ReconnectDomainsResponse\"\xa9\x02\n\x15RegisterDomainRequest\x12W\n\x03\x61\x64\x64\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.DomainConnectionConfigR\x03\x61\x64\x64\x12%\n\x0ehandshake_only\x18\x02 \x01(\x08R\rhandshakeOnly\x12\x8f\x01\n\x1fsequencer_connection_validation\x18\x03 \x01(\x0e\x32G.com.digitalasset.canton.admin.domain.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"\x18\n\x16RegisterDomainResponse\"\x86\x02\n\x13ModifyDomainRequest\x12]\n\x06modify\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.DomainConnectionConfigR\x06modify\x12\x8f\x01\n\x1fsequencer_connection_validation\x18\x02 \x01(\x0e\x32G.com.digitalasset.canton.admin.domain.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"\x16\n\x14ModifyDomainResponse\"\x1e\n\x1cListConfiguredDomainsRequest\"\x96\x02\n\x1dListConfiguredDomainsResponse\x12m\n\x07results\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.admin.participant.v30.ListConfiguredDomainsResponse.ResultR\x07results\x1a\x85\x01\n\x06Result\x12]\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.DomainConnectionConfigR\x06\x63onfig\x12\x1c\n\tconnected\x18\x02 \x01(\x08R\tconnected\"O\n\x14\x43onnectDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x14\n\x05retry\x18\x02 \x01(\x08R\x05retry\"N\n\x15\x43onnectDomainResponse\x12\x35\n\x16\x63onnected_successfully\x18\x01 \x01(\x08R\x15\x63onnectedSuccessfully\"<\n\x17\x44isconnectDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"\x1a\n\x18\x44isconnectDomainResponse\"\x1d\n\x1bListConnectedDomainsRequest\"\x83\x02\n\x1cListConnectedDomainsResponse\x12\x7f\n\x11\x63onnected_domains\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.admin.participant.v30.ListConnectedDomainsResponse.ResultR\x10\x63onnectedDomains\x1a\x62\n\x06Result\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12\x18\n\x07healthy\x18\x03 \x01(\x08R\x07healthy\"7\n\x12GetDomainIdRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"2\n\x13GetDomainIdResponse\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId2\xbc\n\n\x19\x44omainConnectivityService\x12\xa3\x01\n\x10ReconnectDomains\x12\x46.com.digitalasset.canton.admin.participant.v30.ReconnectDomainsRequest\x1aG.com.digitalasset.canton.admin.participant.v30.ReconnectDomainsResponse\x12\x9d\x01\n\x0eRegisterDomain\x12\x44.com.digitalasset.canton.admin.participant.v30.RegisterDomainRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.RegisterDomainResponse\x12\x97\x01\n\x0cModifyDomain\x12\x42.com.digitalasset.canton.admin.participant.v30.ModifyDomainRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ModifyDomainResponse\x12\x9a\x01\n\rConnectDomain\x12\x43.com.digitalasset.canton.admin.participant.v30.ConnectDomainRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.ConnectDomainResponse\x12\xa3\x01\n\x10\x44isconnectDomain\x12\x46.com.digitalasset.canton.admin.participant.v30.DisconnectDomainRequest\x1aG.com.digitalasset.canton.admin.participant.v30.DisconnectDomainResponse\x12\xaf\x01\n\x14ListConnectedDomains\x12J.com.digitalasset.canton.admin.participant.v30.ListConnectedDomainsRequest\x1aK.com.digitalasset.canton.admin.participant.v30.ListConnectedDomainsResponse\x12\xb2\x01\n\x15ListConfiguredDomains\x12K.com.digitalasset.canton.admin.participant.v30.ListConfiguredDomainsRequest\x1aL.com.digitalasset.canton.admin.participant.v30.ListConfiguredDomainsResponse\x12\x94\x01\n\x0bGetDomainId\x12\x41.com.digitalasset.canton.admin.participant.v30.GetDomainIdRequest\x1a\x42.com.digitalasset.canton.admin.participant.v30.GetDomainIdResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.domain_connectivity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_DOMAINCONNECTIONCONFIG']._serialized_start=290
  _globals['_DOMAINCONNECTIONCONFIG']._serialized_end=873
  _globals['_RECONNECTDOMAINSREQUEST']._serialized_start=875
  _globals['_RECONNECTDOMAINSREQUEST']._serialized_end=941
  _globals['_RECONNECTDOMAINSRESPONSE']._serialized_start=943
  _globals['_RECONNECTDOMAINSRESPONSE']._serialized_end=969
  _globals['_REGISTERDOMAINREQUEST']._serialized_start=972
  _globals['_REGISTERDOMAINREQUEST']._serialized_end=1269
  _globals['_REGISTERDOMAINRESPONSE']._serialized_start=1271
  _globals['_REGISTERDOMAINRESPONSE']._serialized_end=1295
  _globals['_MODIFYDOMAINREQUEST']._serialized_start=1298
  _globals['_MODIFYDOMAINREQUEST']._serialized_end=1560
  _globals['_MODIFYDOMAINRESPONSE']._serialized_start=1562
  _globals['_MODIFYDOMAINRESPONSE']._serialized_end=1584
  _globals['_LISTCONFIGUREDDOMAINSREQUEST']._serialized_start=1586
  _globals['_LISTCONFIGUREDDOMAINSREQUEST']._serialized_end=1616
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE']._serialized_start=1619
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE']._serialized_end=1897
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE_RESULT']._serialized_start=1764
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE_RESULT']._serialized_end=1897
  _globals['_CONNECTDOMAINREQUEST']._serialized_start=1899
  _globals['_CONNECTDOMAINREQUEST']._serialized_end=1978
  _globals['_CONNECTDOMAINRESPONSE']._serialized_start=1980
  _globals['_CONNECTDOMAINRESPONSE']._serialized_end=2058
  _globals['_DISCONNECTDOMAINREQUEST']._serialized_start=2060
  _globals['_DISCONNECTDOMAINREQUEST']._serialized_end=2120
  _globals['_DISCONNECTDOMAINRESPONSE']._serialized_start=2122
  _globals['_DISCONNECTDOMAINRESPONSE']._serialized_end=2148
  _globals['_LISTCONNECTEDDOMAINSREQUEST']._serialized_start=2150
  _globals['_LISTCONNECTEDDOMAINSREQUEST']._serialized_end=2179
  _globals['_LISTCONNECTEDDOMAINSRESPONSE']._serialized_start=2182
  _globals['_LISTCONNECTEDDOMAINSRESPONSE']._serialized_end=2441
  _globals['_LISTCONNECTEDDOMAINSRESPONSE_RESULT']._serialized_start=2343
  _globals['_LISTCONNECTEDDOMAINSRESPONSE_RESULT']._serialized_end=2441
  _globals['_GETDOMAINIDREQUEST']._serialized_start=2443
  _globals['_GETDOMAINIDREQUEST']._serialized_end=2498
  _globals['_GETDOMAINIDRESPONSE']._serialized_start=2500
  _globals['_GETDOMAINIDRESPONSE']._serialized_end=2550
  _globals['_DOMAINCONNECTIVITYSERVICE']._serialized_start=2553
  _globals['_DOMAINCONNECTIVITYSERVICE']._serialized_end=3893
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v1/mediator_response.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v1/mediator_response.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;com/digitalasset/canton/protocol/v1/mediator_response.proto\x12#com.digitalasset.canton.protocol.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc3\x02\n\x10MediatorResponse\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x1b\n\tview_hash\x18\x03 \x01(\x0cR\x08viewHash\x12V\n\rlocal_verdict\x18\x04 \x01(\x0b\x32\x31.com.digitalasset.canton.protocol.v1.LocalVerdictR\x0clocalVerdict\x12\x1b\n\troot_hash\x18\x05 \x01(\x0cR\x08rootHash\x12-\n\x12\x63onfirming_parties\x18\x06 \x03(\tR\x11\x63onfirmingParties\x12\x1b\n\tdomain_id\x18\x07 \x01(\tR\x08\x64omainId\"\xba\x01\n\x0cLocalVerdict\x12=\n\rlocal_approve\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x0clocalApprove\x12U\n\x0clocal_reject\x18\x02 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v1.LocalRejectH\x00R\x0blocalRejectB\x14\n\x12some_local_verdict\"\xb2\x01\n\x0bLocalReject\x12!\n\x0c\x63\x61use_prefix\x18\x04 \x01(\tR\x0b\x63\x61usePrefix\x12\x18\n\x07\x64\x65tails\x18\x02 \x01(\tR\x07\x64\x65tails\x12\x1a\n\x08resource\x18\x03 \x03(\tR\x08resource\x12\x1d\n\nerror_code\x18\x05 \x01(\tR\terrorCode\x12%\n\x0e\x65rror_category\x18\x06 \x01(\rR\rerrorCategoryJ\x04\x08\x01\x10\x02\x42TZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v1.mediator_response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1'
  _globals['_MEDIATORRESPONSE']._serialized_start=163
  _globals['_MEDIATORRESPONSE']._serialized_end=486
  _globals['_LOCALVERDICT']._serialized_start=489
  _globals['_LOCALVERDICT']._serialized_end=675
  _globals['_LOCALREJECT']._serialized_start=678
  _globals['_LOCALREJECT']._serialized_end=856
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from google.protobuf.empty_pb2 import Empty
from google.protobuf.timestamp_pb2 import Timestamp
from grpc import aio as _grpc_aio

from .initialization_service_pb2 import GetIdResponse, InitIdRequest, InitIdResponse

__all__ = [
    "InitializationServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class InitializationServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _InitializationServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _InitializationServiceAsyncStub: ...  # type: ignore
    def InitId(self, __1: InitIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[InitIdResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, InitIdResponse]]: ...
    def GetId(self, __1: Empty, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetIdResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetIdResponse]]: ...
    def CurrentTime(self, __1: Empty, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[Timestamp, _grpc_aio.UnaryUnaryCall[_typing.Any, Timestamp]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _InitializationServiceBlockingStub(InitializationServiceStub):
    def InitId(self, __1: InitIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> InitIdResponse: ...
    def GetId(self, __1: Empty, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetIdResponse: ...
    def CurrentTime(self, __1: Empty, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> Timestamp: ...

# noinspection PyPep8Naming,DuplicatedCode
class _InitializationServiceAsyncStub(InitializationServiceStub):
    def InitId(self, __1: InitIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, InitIdResponse]: ...  # type: ignore
    def GetId(self, __1: Empty, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetIdResponse]: ...  # type: ignore
    def CurrentTime(self, __1: Empty, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, Timestamp]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/pruning_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/pruning_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...pruning.v30 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/participant/v30/pruning_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x37\x63om/digitalasset/canton/admin/pruning/v30/pruning.proto\x1a\x1fgoogle/protobuf/timestamp.proto\".\n\x0cPruneRequest\x12\x1e\n\x0bprune_up_to\x18\x01 \x01(\tR\tpruneUpTo\"\x0f\n\rPruneResponse\"z\n\x1bGetSafePruningOffsetRequest\x12<\n\x0c\x62\x65\x66ore_or_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nbeforeOrAt\x12\x1d\n\nledger_end\x18\x02 \x01(\tR\tledgerEnd\"\x8c\x02\n\x1cGetSafePruningOffsetResponse\x12\x30\n\x13safe_pruning_offset\x18\x01 \x01(\tH\x00R\x11safePruningOffset\x12\x96\x01\n\x16no_safe_pruning_offset\x18\x02 \x01(\x0b\x32_.com.digitalasset.canton.admin.participant.v30.GetSafePruningOffsetResponse.NoSafePruningOffsetH\x00R\x13noSafePruningOffset\x1a\x15\n\x13NoSafePruningOffsetB\n\n\x08response2\xc5\x10\n\x0ePruningService\x12\x82\x01\n\x05Prune\x12;.com.digitalasset.canton.admin.participant.v30.PruneRequest\x1a<.com.digitalasset.canton.admin.participant.v30.PruneResponse\x12\xaf\x01\n\x14GetSafePruningOffset\x12J.com.digitalasset.canton.admin.participant.v30.GetSafePruningOffsetRequest\x1aK.com.digitalasset.canton.admin.participant.v30.GetSafePruningOffsetResponse\x12\x8e\x01\n\x0bSetSchedule\x12>.com.digitalasset.canton.admin.pruning.v30.SetSchedule.Request\x1a?.com.digitalasset.canton.admin.pruning.v30.SetSchedule.Response\x12\xaf\x01\n\x16SetParticipantSchedule\x12I.com.digitalasset.canton.admin.pruning.v30.SetParticipantSchedule.Request\x1aJ.com.digitalasset.canton.admin.pruning.v30.SetParticipantSchedule.Response\x12\x82\x01\n\x07SetCron\x12:.com.digitalasset.canton.admin.pruning.v30.SetCron.Request\x1a;.com.digitalasset.canton.admin.pruning.v30.SetCron.Response\x12\x97\x01\n\x0eSetMaxDuration\x12\x41.com.digitalasset.canton.admin.pruning.v30.SetMaxDuration.Request\x1a\x42.com.digitalasset.canton.admin.pruning.v30.SetMaxDuration.Response\x12\x91\x01\n\x0cSetRetention\x12?.com.digitalasset.canton.admin.pruning.v30.SetRetention.Request\x1a@.com.digitalasset.canton.admin.pruning.v30.SetRetention.Response\x12\x94\x01\n\rClearSchedule\x12@.com.digitalasset.canton.admin.pruning.v30.ClearSchedule.Request\x1a\x41.com.digitalasset.canton.admin.pruning.v30.ClearSchedule.Response\x12\x8e\x01\n\x0bGetSchedule\x12>.com.digitalasset.canton.admin.pruning.v30.GetSchedule.Request\x1a?.com.digitalasset.canton.admin.pruning.v30.GetSchedule.Response\x12\xaf\x01\n\x16GetParticipantSchedule\x12I.com.digitalasset.canton.admin.pruning.v30.GetParticipantSchedule.Request\x1aJ.com.digitalasset.canton.admin.pruning.v30.GetParticipantSchedule.Response\x12\xb5\x01\n\x18SetNoWaitCommitmentsFrom\x12K.com.digitalasset.canton.admin.pruning.v30.SetNoWaitCommitmentsFrom.Request\x1aL.com.digitalasset.canton.admin.pruning.v30.SetNoWaitCommitmentsFrom.Response\x12\xbb\x01\n\x1aResetNoWaitCommitmentsFrom\x12M.com.digitalasset.canton.admin.pruning.v30.ResetNoWaitCommitmentsFrom.Request\x1aN.com.digitalasset.canton.admin.pruning.v30.ResetNoWaitCommitmentsFrom.Response\x12\xb5\x01\n\x18GetNoWaitCommitmentsFrom\x12K.com.digitalasset.canton.admin.pruning.v30.GetNoWaitCommitmentsFrom.Request\x1aL.com.digitalasset.canton.admin.pruning.v30.GetNoWaitCommitmentsFrom.ResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.pruning_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_PRUNEREQUEST']._serialized_start=208
  _globals['_PRUNEREQUEST']._serialized_end=254
  _globals['_PRUNERESPONSE']._serialized_start=256
  _globals['_PRUNERESPONSE']._serialized_end=271
  _globals['_GETSAFEPRUNINGOFFSETREQUEST']._serialized_start=273
  _globals['_GETSAFEPRUNINGOFFSETREQUEST']._serialized_end=395
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE']._serialized_start=398
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE']._serialized_end=666
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE_NOSAFEPRUNINGOFFSET']._serialized_start=633
  _globals['_GETSAFEPRUNINGOFFSETRESPONSE_NOSAFEPRUNINGOFFSET']._serialized_end=654
  _globals['_PRUNINGSERVICE']._serialized_start=669
  _globals['_PRUNINGSERVICE']._serialized_end=2786
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/synchronization.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/synchronization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_participant__transaction__pb2
from . import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_participant__transfer__pb2
from . import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:com/digitalasset/canton/protocol/v30/synchronization.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x42\x63om/digitalasset/canton/protocol/v30/participant_transaction.proto\x1a?com/digitalasset/canton/protocol/v30/participant_transfer.proto\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\"\x8c\x02\n!TypedSignedProtocolMessageContent\x12\x35\n\x15\x63onfirmation_response\x18\x02 \x01(\x0cH\x00R\x14\x63onfirmationResponse\x12\x31\n\x13\x63onfirmation_result\x18\x03 \x01(\x0cH\x00R\x12\x63onfirmationResult\x12\'\n\x0e\x61\x63s_commitment\x18\x04 \x01(\x0cH\x00R\racsCommitment\x12\x34\n\x15set_traffic_purchased\x18\x05 \x01(\x0cH\x00R\x13setTrafficPurchasedB\x1e\n\x1csome_signed_protocol_message\"\xb6\x01\n\x15SignedProtocolMessage\x12K\n\tsignature\x18\x01 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\x12P\n%typed_signed_protocol_message_content\x18\x02 \x01(\x0cR!typedSignedProtocolMessageContent\"\x84\x06\n\x0f\x45nvelopeContent\x12\x62\n\x10informee_message\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.InformeeMessageH\x00R\x0finformeeMessage\x12r\n\x16\x65ncrypted_view_message\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.EncryptedViewMessageH\x00R\x14\x65ncryptedViewMessage\x12\x85\x01\n\x1dtransfer_out_mediator_message\x18\x03 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v30.TransferOutMediatorMessageH\x00R\x1atransferOutMediatorMessage\x12\x82\x01\n\x1ctransfer_in_mediator_message\x18\x04 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.TransferInMediatorMessageH\x00R\x19transferInMediatorMessage\x12\x63\n\x11root_hash_message\x18\x05 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.RootHashMessageH\x00R\x0frootHashMessage\x12\x8d\x01\n\x1ftopology_transactions_broadcast\x18\x06 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.TopologyTransactionsBroadcastH\x00R\x1dtopologyTransactionsBroadcastB\x17\n\x15some_envelope_contentBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.synchronization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_TYPEDSIGNEDPROTOCOLMESSAGECONTENT']._serialized_start=336
  _globals['_TYPEDSIGNEDPROTOCOLMESSAGECONTENT']._serialized_end=604
  _globals['_SIGNEDPROTOCOLMESSAGE']._serialized_start=607
  _globals['_SIGNEDPROTOCOLMESSAGE']._serialized_end=789
  _globals['_ENVELOPECONTENT']._serialized_start=792
  _globals['_ENVELOPECONTENT']._serialized_end=1564
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from google.protobuf.empty_pb2 import Empty
from grpc import aio as _grpc_aio

from .vault_service_pb2 import DeleteKeyPairRequest, DeleteKeyPairResponse, ExportKeyPairRequest, ExportKeyPairResponse, GenerateEncryptionKeyRequest, GenerateEncryptionKeyResponse, GenerateSigningKeyRequest, GenerateSigningKeyResponse, GetWrapperKeyIdRequest, GetWrapperKeyIdResponse, ImportKeyPairRequest, ImportKeyPairResponse, ImportPublicKeyRequest, ImportPublicKeyResponse, ListKeysRequest, ListKeysResponse, ListMyKeysResponse, RegisterKmsEncryptionKeyRequest, RegisterKmsEncryptionKeyResponse, RegisterKmsSigningKeyRequest, RegisterKmsSigningKeyResponse, RotateWrapperKeyRequest

__all__ = [
    "VaultServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class VaultServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _VaultServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _VaultServiceAsyncStub: ...  # type: ignore
    def ListMyKeys(self, __1: ListKeysRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListMyKeysResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListMyKeysResponse]]: ...
    def GenerateSigningKey(self, __1: GenerateSigningKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GenerateSigningKeyResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateSigningKeyResponse]]: ...
    def GenerateEncryptionKey(self, __1: GenerateEncryptionKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GenerateEncryptionKeyResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateEncryptionKeyResponse]]: ...
    def RegisterKmsEncryptionKey(self, __1: RegisterKmsEncryptionKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[RegisterKmsEncryptionKeyResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterKmsEncryptionKeyResponse]]: ...
    def RegisterKmsSigningKey(self, __1: RegisterKmsSigningKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[RegisterKmsSigningKeyResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterKmsSigningKeyResponse]]: ...
    def ImportPublicKey(self, __1: ImportPublicKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ImportPublicKeyResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ImportPublicKeyResponse]]: ...
    def ListPublicKeys(self, __1: ListKeysRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ListKeysResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ListKeysResponse]]: ...
    def RotateWrapperKey(self, __1: RotateWrapperKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[Empty, _grpc_aio.UnaryUnaryCall[_typing.Any, Empty]]: ...
    def GetWrapperKeyId(self, __1: GetWrapperKeyIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetWrapperKeyIdResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetWrapperKeyIdResponse]]: ...
    def ExportKeyPair(self, __1: ExportKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ExportKeyPairResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ExportKeyPairResponse]]: ...
    def ImportKeyPair(self, __1: ImportKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[ImportKeyPairResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, ImportKeyPairResponse]]: ...
    def DeleteKeyPair(self, __1: DeleteKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[DeleteKeyPairResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, DeleteKeyPairResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _VaultServiceBlockingStub(VaultServiceStub):
    def ListMyKeys(self, __1: ListKeysRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMyKeysResponse: ...
    def GenerateSigningKey(self, __1: GenerateSigningKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateSigningKeyResponse: ...
    def GenerateEncryptionKey(self, __1: GenerateEncryptionKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GenerateEncryptionKeyResponse: ...
    def RegisterKmsEncryptionKey(self, __1: RegisterKmsEncryptionKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterKmsEncryptionKeyResponse: ...
    def RegisterKmsSigningKey(self, __1: RegisterKmsSigningKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> RegisterKmsSigningKeyResponse: ...
    def ImportPublicKey(self, __1: ImportPublicKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportPublicKeyResponse: ...
    def ListPublicKeys(self, __1: ListKeysRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListKeysResponse: ...
    def RotateWrapperKey(self, __1: RotateWrapperKeyRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> Empty: ...
    def GetWrapperKeyId(self, __1: GetWrapperKeyIdRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetWrapperKeyIdResponse: ...
    def ExportKeyPair(self, __1: ExportKeyPairRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ExportKeyPairResponse: ...
    def ImportKeyPair(self, __1: ImportKeyPairRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ImportKeyPairResponse: ...
    def DeleteKeyPair(self, __1: DeleteKeyPairRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DeleteKeyPairResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _VaultServiceAsyncStub(VaultServiceStub):
    def ListMyKeys(self, __1: ListKeysRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListMyKeysResponse]: ...  # type: ignore
    def GenerateSigningKey(self, __1: GenerateSigningKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateSigningKeyResponse]: ...  # type: ignore
    def GenerateEncryptionKey(self, __1: GenerateEncryptionKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GenerateEncryptionKeyResponse]: ...  # type: ignore
    def RegisterKmsEncryptionKey(self, __1: RegisterKmsEncryptionKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterKmsEncryptionKeyResponse]: ...  # type: ignore
    def RegisterKmsSigningKey(self, __1: RegisterKmsSigningKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, RegisterKmsSigningKeyResponse]: ...  # type: ignore
    def ImportPublicKey(self, __1: ImportPublicKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportPublicKeyResponse]: ...  # type: ignore
    def ListPublicKeys(self, __1: ListKeysRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListKeysResponse]: ...  # type: ignore
    def RotateWrapperKey(self, __1: RotateWrapperKeyRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, Empty]: ...  # type: ignore
    def GetWrapperKeyId(self, __1: GetWrapperKeyIdRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetWrapperKeyIdResponse]: ...  # type: ignore
    def ExportKeyPair(self, __1: ExportKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ExportKeyPairResponse]: ...  # type: ignore
    def ImportKeyPair(self, __1: ImportKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ImportKeyPairResponse]: ...  # type: ignore
    def DeleteKeyPair(self, __1: DeleteKeyPairRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, DeleteKeyPairResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import vault_service_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/crypto/admin/v0/vault_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class VaultServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListMyKeys = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/ListMyKeys',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListMyKeysResponse.FromString,
                _registered_method=True)
        self.GenerateSigningKey = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/GenerateSigningKey',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateSigningKeyRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateSigningKeyResponse.FromString,
                _registered_method=True)
        self.GenerateEncryptionKey = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/GenerateEncryptionKey',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateEncryptionKeyRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateEncryptionKeyResponse.FromString,
                _registered_method=True)
        self.RegisterKmsEncryptionKey = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/RegisterKmsEncryptionKey',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsEncryptionKeyRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsEncryptionKeyResponse.FromString,
                _registered_method=True)
        self.RegisterKmsSigningKey = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/RegisterKmsSigningKey',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsSigningKeyRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsSigningKeyResponse.FromString,
                _registered_method=True)
        self.ImportPublicKey = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/ImportPublicKey',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportPublicKeyRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportPublicKeyResponse.FromString,
                _registered_method=True)
        self.ListPublicKeys = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/ListPublicKeys',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysResponse.FromString,
                _registered_method=True)
        self.RotateWrapperKey = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/RotateWrapperKey',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RotateWrapperKeyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)
        self.GetWrapperKeyId = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/GetWrapperKeyId',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GetWrapperKeyIdRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GetWrapperKeyIdResponse.FromString,
                _registered_method=True)
        self.ExportKeyPair = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/ExportKeyPair',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ExportKeyPairRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ExportKeyPairResponse.FromString,
                _registered_method=True)
        self.ImportKeyPair = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/ImportKeyPair',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportKeyPairRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportKeyPairResponse.FromString,
                _registered_method=True)
        self.DeleteKeyPair = channel.unary_unary(
                '/com.digitalasset.canton.crypto.admin.v0.VaultService/DeleteKeyPair',
                request_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.DeleteKeyPairRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.DeleteKeyPairResponse.FromString,
                _registered_method=True)


class VaultServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListMyKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateSigningKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateEncryptionKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterKmsEncryptionKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterKmsSigningKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportPublicKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPublicKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RotateWrapperKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWrapperKeyId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportKeyPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportKeyPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteKeyPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VaultServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListMyKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMyKeys,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListMyKeysResponse.SerializeToString,
            ),
            'GenerateSigningKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateSigningKey,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateSigningKeyRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateSigningKeyResponse.SerializeToString,
            ),
            'GenerateEncryptionKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateEncryptionKey,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateEncryptionKeyRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateEncryptionKeyResponse.SerializeToString,
            ),
            'RegisterKmsEncryptionKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterKmsEncryptionKey,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsEncryptionKeyRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsEncryptionKeyResponse.SerializeToString,
            ),
            'RegisterKmsSigningKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterKmsSigningKey,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsSigningKeyRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsSigningKeyResponse.SerializeToString,
            ),
            'ImportPublicKey': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportPublicKey,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportPublicKeyRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportPublicKeyResponse.SerializeToString,
            ),
            'ListPublicKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPublicKeys,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysResponse.SerializeToString,
            ),
            'RotateWrapperKey': grpc.unary_unary_rpc_method_handler(
                    servicer.RotateWrapperKey,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RotateWrapperKeyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetWrapperKeyId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWrapperKeyId,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GetWrapperKeyIdRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GetWrapperKeyIdResponse.SerializeToString,
            ),
            'ExportKeyPair': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportKeyPair,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ExportKeyPairRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ExportKeyPairResponse.SerializeToString,
            ),
            'ImportKeyPair': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportKeyPair,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportKeyPairRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportKeyPairResponse.SerializeToString,
            ),
            'DeleteKeyPair': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteKeyPair,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.DeleteKeyPairRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.DeleteKeyPairResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.crypto.admin.v0.VaultService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.crypto.admin.v0.VaultService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VaultService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListMyKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/ListMyKeys',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListMyKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenerateSigningKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/GenerateSigningKey',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateSigningKeyRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateSigningKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenerateEncryptionKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/GenerateEncryptionKey',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateEncryptionKeyRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GenerateEncryptionKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterKmsEncryptionKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/RegisterKmsEncryptionKey',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsEncryptionKeyRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsEncryptionKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisterKmsSigningKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/RegisterKmsSigningKey',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsSigningKeyRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RegisterKmsSigningKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ImportPublicKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/ImportPublicKey',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportPublicKeyRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportPublicKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPublicKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/ListPublicKeys',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ListKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RotateWrapperKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/RotateWrapperKey',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.RotateWrapperKeyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetWrapperKeyId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/GetWrapperKeyId',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GetWrapperKeyIdRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.GetWrapperKeyIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportKeyPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/ExportKeyPair',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ExportKeyPairRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ExportKeyPairResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ImportKeyPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/ImportKeyPair',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportKeyPairRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.ImportKeyPairResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteKeyPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.crypto.admin.v0.VaultService/DeleteKeyPair',
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.DeleteKeyPairRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_crypto_dot_admin_dot_v0_dot_vault__service__pb2.DeleteKeyPairResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v30 import crypto_pb2 as _crypto_pb2
from . import domain_parameters_pb2 as _domain_parameters_pb2
from . import sequencing_parameters_pb2 as _sequencing_parameters_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Enums(_message.Message):
    __slots__ = ()
    class TopologyChangeOp(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TOPOLOGY_CHANGE_OP_UNSPECIFIED: _ClassVar[Enums.TopologyChangeOp]
        TOPOLOGY_CHANGE_OP_ADD_REPLACE: _ClassVar[Enums.TopologyChangeOp]
        TOPOLOGY_CHANGE_OP_REMOVE: _ClassVar[Enums.TopologyChangeOp]
    TOPOLOGY_CHANGE_OP_UNSPECIFIED: Enums.TopologyChangeOp
    TOPOLOGY_CHANGE_OP_ADD_REPLACE: Enums.TopologyChangeOp
    TOPOLOGY_CHANGE_OP_REMOVE: Enums.TopologyChangeOp
    class ParticipantPermission(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PARTICIPANT_PERMISSION_UNSPECIFIED: _ClassVar[Enums.ParticipantPermission]
        PARTICIPANT_PERMISSION_SUBMISSION: _ClassVar[Enums.ParticipantPermission]
        PARTICIPANT_PERMISSION_CONFIRMATION: _ClassVar[Enums.ParticipantPermission]
        PARTICIPANT_PERMISSION_OBSERVATION: _ClassVar[Enums.ParticipantPermission]
    PARTICIPANT_PERMISSION_UNSPECIFIED: Enums.ParticipantPermission
    PARTICIPANT_PERMISSION_SUBMISSION: Enums.ParticipantPermission
    PARTICIPANT_PERMISSION_CONFIRMATION: Enums.ParticipantPermission
    PARTICIPANT_PERMISSION_OBSERVATION: Enums.ParticipantPermission
    def __init__(self) -> None: ...

class NamespaceDelegation(_message.Message):
    __slots__ = ("namespace", "target_key", "is_root_delegation")
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    TARGET_KEY_FIELD_NUMBER: _ClassVar[int]
    IS_ROOT_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    namespace: str
    target_key: _crypto_pb2.SigningPublicKey
    is_root_delegation: bool
    def __init__(self, namespace: _Optional[str] = ..., target_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ..., is_root_delegation: bool = ...) -> None: ...

class DecentralizedNamespaceDefinition(_message.Message):
    __slots__ = ("decentralized_namespace", "threshold", "owners")
    DECENTRALIZED_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    decentralized_namespace: str
    threshold: int
    owners: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, decentralized_namespace: _Optional[str] = ..., threshold: _Optional[int] = ..., owners: _Optional[_Iterable[str]] = ...) -> None: ...

class IdentifierDelegation(_message.Message):
    __slots__ = ("unique_identifier", "target_key")
    UNIQUE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    TARGET_KEY_FIELD_NUMBER: _ClassVar[int]
    unique_identifier: str
    target_key: _crypto_pb2.SigningPublicKey
    def __init__(self, unique_identifier: _Optional[str] = ..., target_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ...) -> None: ...

class OwnerToKeyMapping(_message.Message):
    __slots__ = ("member", "public_keys", "domain")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    member: str
    public_keys: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.PublicKey]
    domain: str
    def __init__(self, member: _Optional[str] = ..., public_keys: _Optional[_Iterable[_Union[_crypto_pb2.PublicKey, _Mapping]]] = ..., domain: _Optional[str] = ...) -> None: ...

class PartyToKeyMapping(_message.Message):
    __slots__ = ("party", "domain", "threshold", "signing_keys")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    SIGNING_KEYS_FIELD_NUMBER: _ClassVar[int]
    party: str
    domain: str
    threshold: int
    signing_keys: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.SigningPublicKey]
    def __init__(self, party: _Optional[str] = ..., domain: _Optional[str] = ..., threshold: _Optional[int] = ..., signing_keys: _Optional[_Iterable[_Union[_crypto_pb2.SigningPublicKey, _Mapping]]] = ...) -> None: ...

class DomainTrustCertificate(_message.Message):
    __slots__ = ("participant_uid", "domain", "transfer_only_to_given_target_domains", "target_domains")
    PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_ONLY_TO_GIVEN_TARGET_DOMAINS_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAINS_FIELD_NUMBER: _ClassVar[int]
    participant_uid: str
    domain: str
    transfer_only_to_given_target_domains: bool
    target_domains: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, participant_uid: _Optional[str] = ..., domain: _Optional[str] = ..., transfer_only_to_given_target_domains: bool = ..., target_domains: _Optional[_Iterable[str]] = ...) -> None: ...

class ParticipantDomainPermission(_message.Message):
    __slots__ = ("domain", "participant_uid", "permission", "limits", "login_after")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    LIMITS_FIELD_NUMBER: _ClassVar[int]
    LOGIN_AFTER_FIELD_NUMBER: _ClassVar[int]
    domain: str
    participant_uid: str
    permission: Enums.ParticipantPermission
    limits: _domain_parameters_pb2.ParticipantDomainLimits
    login_after: _wrappers_pb2.Int64Value
    def __init__(self, domain: _Optional[str] = ..., participant_uid: _Optional[str] = ..., permission: _Optional[_Union[Enums.ParticipantPermission, str]] = ..., limits: _Optional[_Union[_domain_parameters_pb2.ParticipantDomainLimits, _Mapping]] = ..., login_after: _Optional[_Union[_wrappers_pb2.Int64Value, _Mapping]] = ...) -> None: ...

class PartyHostingLimits(_message.Message):
    __slots__ = ("domain", "party", "quota")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    PARTY_FIELD_NUMBER: _ClassVar[int]
    QUOTA_FIELD_NUMBER: _ClassVar[int]
    domain: str
    party: str
    quota: int
    def __init__(self, domain: _Optional[str] = ..., party: _Optional[str] = ..., quota: _Optional[int] = ...) -> None: ...

class VettedPackages(_message.Message):
    __slots__ = ("participant_uid", "package_ids", "domain")
    PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_IDS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    participant_uid: str
    package_ids: _containers.RepeatedScalarFieldContainer[str]
    domain: str
    def __init__(self, participant_uid: _Optional[str] = ..., package_ids: _Optional[_Iterable[str]] = ..., domain: _Optional[str] = ...) -> None: ...

class PartyToParticipant(_message.Message):
    __slots__ = ("party", "threshold", "participants", "group_addressing", "domain")
    class HostingParticipant(_message.Message):
        __slots__ = ("participant_uid", "permission")
        PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
        PERMISSION_FIELD_NUMBER: _ClassVar[int]
        participant_uid: str
        permission: Enums.ParticipantPermission
        def __init__(self, participant_uid: _Optional[str] = ..., permission: _Optional[_Union[Enums.ParticipantPermission, str]] = ...) -> None: ...
    PARTY_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ADDRESSING_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    party: str
    threshold: int
    participants: _containers.RepeatedCompositeFieldContainer[PartyToParticipant.HostingParticipant]
    group_addressing: bool
    domain: str
    def __init__(self, party: _Optional[str] = ..., threshold: _Optional[int] = ..., participants: _Optional[_Iterable[_Union[PartyToParticipant.HostingParticipant, _Mapping]]] = ..., group_addressing: bool = ..., domain: _Optional[str] = ...) -> None: ...

class AuthorityOf(_message.Message):
    __slots__ = ("party", "threshold", "parties", "domain")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    party: str
    threshold: int
    parties: _containers.RepeatedScalarFieldContainer[str]
    domain: str
    def __init__(self, party: _Optional[str] = ..., threshold: _Optional[int] = ..., parties: _Optional[_Iterable[str]] = ..., domain: _Optional[str] = ...) -> None: ...

class DomainParametersState(_message.Message):
    __slots__ = ("domain", "domain_parameters")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    domain_parameters: _domain_parameters_pb2.DynamicDomainParameters
    def __init__(self, domain: _Optional[str] = ..., domain_parameters: _Optional[_Union[_domain_parameters_pb2.DynamicDomainParameters, _Mapping]] = ...) -> None: ...

class DynamicSequencingParametersState(_message.Message):
    __slots__ = ("domain", "sequencing_parameters")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    SEQUENCING_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    sequencing_parameters: _sequencing_parameters_pb2.DynamicSequencingParameters
    def __init__(self, domain: _Optional[str] = ..., sequencing_parameters: _Optional[_Union[_sequencing_parameters_pb2.DynamicSequencingParameters, _Mapping]] = ...) -> None: ...

class MediatorDomainState(_message.Message):
    __slots__ = ("domain", "group", "threshold", "active", "observers")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBSERVERS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    group: int
    threshold: int
    active: _containers.RepeatedScalarFieldContainer[str]
    observers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, domain: _Optional[str] = ..., group: _Optional[int] = ..., threshold: _Optional[int] = ..., active: _Optional[_Iterable[str]] = ..., observers: _Optional[_Iterable[str]] = ...) -> None: ...

class SequencerDomainState(_message.Message):
    __slots__ = ("domain", "threshold", "active", "observers")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBSERVERS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    threshold: int
    active: _containers.RepeatedScalarFieldContainer[str]
    observers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, domain: _Optional[str] = ..., threshold: _Optional[int] = ..., active: _Optional[_Iterable[str]] = ..., observers: _Optional[_Iterable[str]] = ...) -> None: ...

class PurgeTopologyTransaction(_message.Message):
    __slots__ = ("domain", "mappings")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    mappings: _containers.RepeatedCompositeFieldContainer[TopologyMapping]
    def __init__(self, domain: _Optional[str] = ..., mappings: _Optional[_Iterable[_Union[TopologyMapping, _Mapping]]] = ...) -> None: ...

class TopologyMapping(_message.Message):
    __slots__ = ("namespace_delegation", "identifier_delegation", "decentralized_namespace_definition", "owner_to_key_mapping", "domain_trust_certificate", "participant_permission", "party_hosting_limits", "vetted_packages", "party_to_participant", "authority_of", "domain_parameters_state", "mediator_domain_state", "sequencer_domain_state", "purge_topology_txs", "sequencing_dynamic_parameters_state", "party_to_key_mapping")
    NAMESPACE_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    DECENTRALIZED_NAMESPACE_DEFINITION_FIELD_NUMBER: _ClassVar[int]
    OWNER_TO_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_TRUST_CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PARTY_HOSTING_LIMITS_FIELD_NUMBER: _ClassVar[int]
    VETTED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    PARTY_TO_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_OF_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_STATE_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_DOMAIN_STATE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_DOMAIN_STATE_FIELD_NUMBER: _ClassVar[int]
    PURGE_TOPOLOGY_TXS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCING_DYNAMIC_PARAMETERS_STATE_FIELD_NUMBER: _ClassVar[int]
    PARTY_TO_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    namespace_delegation: NamespaceDelegation
    identifier_delegation: IdentifierDelegation
    decentralized_namespace_definition: DecentralizedNamespaceDefinition
    owner_to_key_mapping: OwnerToKeyMapping
    domain_trust_certificate: DomainTrustCertificate
    participant_permission: ParticipantDomainPermission
    party_hosting_limits: PartyHostingLimits
    vetted_packages: VettedPackages
    party_to_participant: PartyToParticipant
    authority_of: AuthorityOf
    domain_parameters_state: DomainParametersState
    mediator_domain_state: MediatorDomainState
    sequencer_domain_state: SequencerDomainState
    purge_topology_txs: PurgeTopologyTransaction
    sequencing_dynamic_parameters_state: DynamicSequencingParametersState
    party_to_key_mapping: PartyToKeyMapping
    def __init__(self, namespace_delegation: _Optional[_Union[NamespaceDelegation, _Mapping]] = ..., identifier_delegation: _Optional[_Union[IdentifierDelegation, _Mapping]] = ..., decentralized_namespace_definition: _Optional[_Union[DecentralizedNamespaceDefinition, _Mapping]] = ..., owner_to_key_mapping: _Optional[_Union[OwnerToKeyMapping, _Mapping]] = ..., domain_trust_certificate: _Optional[_Union[DomainTrustCertificate, _Mapping]] = ..., participant_permission: _Optional[_Union[ParticipantDomainPermission, _Mapping]] = ..., party_hosting_limits: _Optional[_Union[PartyHostingLimits, _Mapping]] = ..., vetted_packages: _Optional[_Union[VettedPackages, _Mapping]] = ..., party_to_participant: _Optional[_Union[PartyToParticipant, _Mapping]] = ..., authority_of: _Optional[_Union[AuthorityOf, _Mapping]] = ..., domain_parameters_state: _Optional[_Union[DomainParametersState, _Mapping]] = ..., mediator_domain_state: _Optional[_Union[MediatorDomainState, _Mapping]] = ..., sequencer_domain_state: _Optional[_Union[SequencerDomainState, _Mapping]] = ..., purge_topology_txs: _Optional[_Union[PurgeTopologyTransaction, _Mapping]] = ..., sequencing_dynamic_parameters_state: _Optional[_Union[DynamicSequencingParametersState, _Mapping]] = ..., party_to_key_mapping: _Optional[_Union[PartyToKeyMapping, _Mapping]] = ...) -> None: ...

class TopologyTransaction(_message.Message):
    __slots__ = ("operation", "serial", "mapping")
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    MAPPING_FIELD_NUMBER: _ClassVar[int]
    operation: Enums.TopologyChangeOp
    serial: int
    mapping: TopologyMapping
    def __init__(self, operation: _Optional[_Union[Enums.TopologyChangeOp, str]] = ..., serial: _Optional[int] = ..., mapping: _Optional[_Union[TopologyMapping, _Mapping]] = ...) -> None: ...

class SignedTopologyTransaction(_message.Message):
    __slots__ = ("transaction", "signatures", "proposal")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    transaction: bytes
    signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    proposal: bool
    def __init__(self, transaction: _Optional[bytes] = ..., signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ..., proposal: bool = ...) -> None: ...

class TopologyTransactionsBroadcast(_message.Message):
    __slots__ = ("domain", "broadcasts")
    class Broadcast(_message.Message):
        __slots__ = ("broadcast_id", "transactions")
        BROADCAST_ID_FIELD_NUMBER: _ClassVar[int]
        TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
        broadcast_id: str
        transactions: _containers.RepeatedCompositeFieldContainer[SignedTopologyTransaction]
        def __init__(self, broadcast_id: _Optional[str] = ..., transactions: _Optional[_Iterable[_Union[SignedTopologyTransaction, _Mapping]]] = ...) -> None: ...
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    BROADCASTS_FIELD_NUMBER: _ClassVar[int]
    domain: str
    broadcasts: _containers.RepeatedCompositeFieldContainer[TopologyTransactionsBroadcast.Broadcast]
    def __init__(self, domain: _Optional[str] = ..., broadcasts: _Optional[_Iterable[_Union[TopologyTransactionsBroadcast.Broadcast, _Mapping]]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/api/v30/sequencer_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/api/v30/sequencer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from ....topology.admin.v30 import topology_ext_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__ext__pb2
from ....v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>com/digitalasset/canton/domain/api/v30/sequencer_service.proto\x12&com.digitalasset.canton.domain.api.v30\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a=com/digitalasset/canton/topology/admin/v30/topology_ext.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\"W\n\x19SendAsyncVersionedRequest\x12:\n\x19signed_submission_request\x18\x01 \x01(\x0cR\x17signedSubmissionRequest\"\xf8\x01\n\x19TrafficControlErrorReason\x12]\n\x05\x65rror\x18\x01 \x01(\x0b\x32G.com.digitalasset.canton.domain.api.v30.TrafficControlErrorReason.ErrorR\x05\x65rror\x1a|\n\x05\x45rror\x12\x33\n\x14insufficient_traffic\x18\x01 \x01(\tH\x00R\x13insufficientTraffic\x12\x34\n\x15outdated_traffic_cost\x18\x02 \x01(\tH\x00R\x13outdatedTrafficCostB\x08\n\x06reason\"\xd5\x04\n\x1aSendAsyncVersionedResponse\x12^\n\x05\x65rror\x18\x01 \x01(\x0b\x32H.com.digitalasset.canton.domain.api.v30.SendAsyncVersionedResponse.ErrorR\x05\x65rror\x1a\xd6\x03\n\x05\x45rror\x12)\n\x0frequest_invalid\x18\x01 \x01(\tH\x00R\x0erequestInvalid\x12)\n\x0frequest_refused\x18\x02 \x01(\tH\x00R\x0erequestRefused\x12 \n\noverloaded\x18\x03 \x01(\tH\x00R\noverloaded\x12\'\n\x0esender_unknown\x18\x04 \x01(\tH\x00R\rsenderUnknown\x12%\n\rshutting_down\x18\x05 \x01(\tH\x00R\x0cshuttingDown\x12\"\n\x0bunavailable\x18\x06 \x01(\tH\x00R\x0bunavailable\x12/\n\x12unknown_recipients\x18\x07 \x01(\tH\x00R\x11unknownRecipients\x12\x1c\n\x08internal\x18\x08 \x01(\tH\x00R\x08internal\x12\x1a\n\x07generic\x18\t \x01(\tH\x00R\x07generic\x12l\n\x0ftraffic_control\x18\n \x01(\x0b\x32\x41.com.digitalasset.canton.domain.api.v30.TrafficControlErrorReasonH\x00R\x0etrafficControlB\x08\n\x06reason\"G\n\x13SubscriptionRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x18\n\x07\x63ounter\x18\x02 \x01(\x03R\x07\x63ounter\"\xa5\x01\n\x1dVersionedSubscriptionResponse\x12\x34\n\x16signed_sequenced_event\x18\x01 \x01(\x0cR\x14signedSequencedEvent\x12N\n\rtrace_context\x18\x02 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContext\"J\n\x12\x41\x63knowledgeRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\"\x15\n\x13\x41\x63knowledgeResponse\"X\n\x18\x41\x63knowledgeSignedRequest\x12<\n\x1asigned_acknowledge_request\x18\x01 \x01(\x0cR\x18signedAcknowledgeRequest\"\x1b\n\x19\x41\x63knowledgeSignedResponse\"=\n#DownloadTopologyStateForInitRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\"\x9d\x01\n$DownloadTopologyStateForInitResponse\x12u\n\x15topology_transactions\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x14topologyTransactions\"W\n\x1fGetTrafficStateForMemberRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\"{\n GetTrafficStateForMemberResponse\x12W\n\rtraffic_state\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.TrafficStateR\x0ctrafficState\"\x8a\x01\n\x1aSequencedEventTrafficState\x12\x36\n\x17\x65xtra_traffic_remainder\x18\x02 \x01(\x04R\x15\x65xtraTrafficRemainder\x12\x34\n\x16\x65xtra_traffic_consumed\x18\x03 \x01(\x04R\x14\x65xtraTrafficConsumed2\xd6\x06\n\x10SequencerService\x12\x9b\x01\n\x12SendAsyncVersioned\x12\x41.com.digitalasset.canton.domain.api.v30.SendAsyncVersionedRequest\x1a\x42.com.digitalasset.canton.domain.api.v30.SendAsyncVersionedResponse\x12\x9a\x01\n\x12SubscribeVersioned\x12;.com.digitalasset.canton.domain.api.v30.SubscriptionRequest\x1a\x45.com.digitalasset.canton.domain.api.v30.VersionedSubscriptionResponse0\x01\x12\x98\x01\n\x11\x41\x63knowledgeSigned\x12@.com.digitalasset.canton.domain.api.v30.AcknowledgeSignedRequest\x1a\x41.com.digitalasset.canton.domain.api.v30.AcknowledgeSignedResponse\x12\xbb\x01\n\x1c\x44ownloadTopologyStateForInit\x12K.com.digitalasset.canton.domain.api.v30.DownloadTopologyStateForInitRequest\x1aL.com.digitalasset.canton.domain.api.v30.DownloadTopologyStateForInitResponse0\x01\x12\xad\x01\n\x18GetTrafficStateForMember\x12G.com.digitalasset.canton.domain.api.v30.GetTrafficStateForMemberRequest\x1aH.com.digitalasset.canton.domain.api.v30.GetTrafficStateForMemberResponseBWZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.api.v30.sequencer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/api/v30'
  _globals['_SENDASYNCVERSIONEDREQUEST']._serialized_start=289
  _globals['_SENDASYNCVERSIONEDREQUEST']._serialized_end=376
  _globals['_TRAFFICCONTROLERRORREASON']._serialized_start=379
  _globals['_TRAFFICCONTROLERRORREASON']._serialized_end=627
  _globals['_TRAFFICCONTROLERRORREASON_ERROR']._serialized_start=503
  _globals['_TRAFFICCONTROLERRORREASON_ERROR']._serialized_end=627
  _globals['_SENDASYNCVERSIONEDRESPONSE']._serialized_start=630
  _globals['_SENDASYNCVERSIONEDRESPONSE']._serialized_end=1227
  _globals['_SENDASYNCVERSIONEDRESPONSE_ERROR']._serialized_start=757
  _globals['_SENDASYNCVERSIONEDRESPONSE_ERROR']._serialized_end=1227
  _globals['_SUBSCRIPTIONREQUEST']._serialized_start=1229
  _globals['_SUBSCRIPTIONREQUEST']._serialized_end=1300
  _globals['_VERSIONEDSUBSCRIPTIONRESPONSE']._serialized_start=1303
  _globals['_VERSIONEDSUBSCRIPTIONRESPONSE']._serialized_end=1468
  _globals['_ACKNOWLEDGEREQUEST']._serialized_start=1470
  _globals['_ACKNOWLEDGEREQUEST']._serialized_end=1544
  _globals['_ACKNOWLEDGERESPONSE']._serialized_start=1546
  _globals['_ACKNOWLEDGERESPONSE']._serialized_end=1567
  _globals['_ACKNOWLEDGESIGNEDREQUEST']._serialized_start=1569
  _globals['_ACKNOWLEDGESIGNEDREQUEST']._serialized_end=1657
  _globals['_ACKNOWLEDGESIGNEDRESPONSE']._serialized_start=1659
  _globals['_ACKNOWLEDGESIGNEDRESPONSE']._serialized_end=1686
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITREQUEST']._serialized_start=1688
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITREQUEST']._serialized_end=1749
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITRESPONSE']._serialized_start=1752
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITRESPONSE']._serialized_end=1909
  _globals['_GETTRAFFICSTATEFORMEMBERREQUEST']._serialized_start=1911
  _globals['_GETTRAFFICSTATEFORMEMBERREQUEST']._serialized_end=1998
  _globals['_GETTRAFFICSTATEFORMEMBERRESPONSE']._serialized_start=2000
  _globals['_GETTRAFFICSTATEFORMEMBERRESPONSE']._serialized_end=2123
  _globals['_SEQUENCEDEVENTTRAFFICSTATE']._serialized_start=2126
  _globals['_SEQUENCEDEVENTTRAFFICSTATE']._serialized_end=2264
  _globals['_SEQUENCERSERVICE']._serialized_start=2267
  _globals['_SEQUENCERSERVICE']._serialized_end=3121
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from typing import Tuple

__all__ = ["get_root_name"]


def get_root_name(s: str, /) -> Tuple[str, str]:
    for suffix in ("_pb2_grpc.py", "_pb2.pyi", "_pb2.py", ".proto", "_grpc.pb.go", ".pb.go"):
        if s.endswith(suffix):
            return s[: -len(suffix)], s[-len(suffix) :]
    raise ValueError(f"unknown file name pattern: {s}")



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopologyQueueStatus(_message.Message):
    __slots__ = ("manager", "dispatcher", "clients")
    MANAGER_FIELD_NUMBER: _ClassVar[int]
    DISPATCHER_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    manager: int
    dispatcher: int
    clients: int
    def __init__(self, manager: _Optional[int] = ..., dispatcher: _Optional[int] = ..., clients: _Optional[int] = ...) -> None: ...

class StatusRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class StatusResponse(_message.Message):
    __slots__ = ("not_initialized", "success")
    class Status(_message.Message):
        __slots__ = ("id", "uptime", "ports", "extra", "active", "topology_queues", "components")
        class PortsEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: int
            def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
        ID_FIELD_NUMBER: _ClassVar[int]
        UPTIME_FIELD_NUMBER: _ClassVar[int]
        PORTS_FIELD_NUMBER: _ClassVar[int]
        EXTRA_FIELD_NUMBER: _ClassVar[int]
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        TOPOLOGY_QUEUES_FIELD_NUMBER: _ClassVar[int]
        COMPONENTS_FIELD_NUMBER: _ClassVar[int]
        id: str
        uptime: _duration_pb2.Duration
        ports: _containers.ScalarMap[str, int]
        extra: bytes
        active: bool
        topology_queues: TopologyQueueStatus
        components: _containers.RepeatedCompositeFieldContainer[StatusResponse.ComponentStatus]
        def __init__(self, id: _Optional[str] = ..., uptime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., ports: _Optional[_Mapping[str, int]] = ..., extra: _Optional[bytes] = ..., active: bool = ..., topology_queues: _Optional[_Union[TopologyQueueStatus, _Mapping]] = ..., components: _Optional[_Iterable[_Union[StatusResponse.ComponentStatus, _Mapping]]] = ...) -> None: ...
    class ComponentStatus(_message.Message):
        __slots__ = ("name", "ok", "degraded", "failed", "fatal")
        class StatusData(_message.Message):
            __slots__ = ("description",)
            DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
            description: _wrappers_pb2.StringValue
            def __init__(self, description: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...
        NAME_FIELD_NUMBER: _ClassVar[int]
        OK_FIELD_NUMBER: _ClassVar[int]
        DEGRADED_FIELD_NUMBER: _ClassVar[int]
        FAILED_FIELD_NUMBER: _ClassVar[int]
        FATAL_FIELD_NUMBER: _ClassVar[int]
        name: str
        ok: StatusResponse.ComponentStatus.StatusData
        degraded: StatusResponse.ComponentStatus.StatusData
        failed: StatusResponse.ComponentStatus.StatusData
        fatal: StatusResponse.ComponentStatus.StatusData
        def __init__(self, name: _Optional[str] = ..., ok: _Optional[_Union[StatusResponse.ComponentStatus.StatusData, _Mapping]] = ..., degraded: _Optional[_Union[StatusResponse.ComponentStatus.StatusData, _Mapping]] = ..., failed: _Optional[_Union[StatusResponse.ComponentStatus.StatusData, _Mapping]] = ..., fatal: _Optional[_Union[StatusResponse.ComponentStatus.StatusData, _Mapping]] = ...) -> None: ...
    class NotInitialized(_message.Message):
        __slots__ = ("active", "waiting_for_external_input")
        class WaitingForExternalInput(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            WAITING_FOR_EXTERNAL_INPUT_UNSPECIFIED: _ClassVar[StatusResponse.NotInitialized.WaitingForExternalInput]
            WAITING_FOR_EXTERNAL_INPUT_ID: _ClassVar[StatusResponse.NotInitialized.WaitingForExternalInput]
            WAITING_FOR_EXTERNAL_INPUT_NODE_TOPOLOGY: _ClassVar[StatusResponse.NotInitialized.WaitingForExternalInput]
            WAITING_FOR_EXTERNAL_INPUT_INITIALIZATION: _ClassVar[StatusResponse.NotInitialized.WaitingForExternalInput]
        WAITING_FOR_EXTERNAL_INPUT_UNSPECIFIED: StatusResponse.NotInitialized.WaitingForExternalInput
        WAITING_FOR_EXTERNAL_INPUT_ID: StatusResponse.NotInitialized.WaitingForExternalInput
        WAITING_FOR_EXTERNAL_INPUT_NODE_TOPOLOGY: StatusResponse.NotInitialized.WaitingForExternalInput
        WAITING_FOR_EXTERNAL_INPUT_INITIALIZATION: StatusResponse.NotInitialized.WaitingForExternalInput
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        WAITING_FOR_EXTERNAL_INPUT_FIELD_NUMBER: _ClassVar[int]
        active: bool
        waiting_for_external_input: StatusResponse.NotInitialized.WaitingForExternalInput
        def __init__(self, active: bool = ..., waiting_for_external_input: _Optional[_Union[StatusResponse.NotInitialized.WaitingForExternalInput, str]] = ...) -> None: ...
    NOT_INITIALIZED_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    not_initialized: StatusResponse.NotInitialized
    success: StatusResponse.Status
    def __init__(self, not_initialized: _Optional[_Union[StatusResponse.NotInitialized, _Mapping]] = ..., success: _Optional[_Union[StatusResponse.Status, _Mapping]] = ...) -> None: ...

class HealthDumpRequest(_message.Message):
    __slots__ = ("chunk_size",)
    CHUNK_SIZE_FIELD_NUMBER: _ClassVar[int]
    chunk_size: _wrappers_pb2.UInt32Value
    def __init__(self, chunk_size: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...

class HealthDumpResponse(_message.Message):
    __slots__ = ("chunk",)
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    chunk: bytes
    def __init__(self, chunk: _Optional[bytes] = ...) -> None: ...

class ParticipantStatusInfo(_message.Message):
    __slots__ = ("connected_domains", "active")
    class ConnectedDomain(_message.Message):
        __slots__ = ("domain", "healthy")
        DOMAIN_FIELD_NUMBER: _ClassVar[int]
        HEALTHY_FIELD_NUMBER: _ClassVar[int]
        domain: str
        healthy: bool
        def __init__(self, domain: _Optional[str] = ..., healthy: bool = ...) -> None: ...
    CONNECTED_DOMAINS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    connected_domains: _containers.RepeatedCompositeFieldContainer[ParticipantStatusInfo.ConnectedDomain]
    active: bool
    def __init__(self, connected_domains: _Optional[_Iterable[_Union[ParticipantStatusInfo.ConnectedDomain, _Mapping]]] = ..., active: bool = ...) -> None: ...

class SequencerNodeStatus(_message.Message):
    __slots__ = ("connected_participant_uids", "sequencer", "domain_id", "admin")
    CONNECTED_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    connected_participant_uids: _containers.RepeatedScalarFieldContainer[str]
    sequencer: SequencerHealthStatus
    domain_id: str
    admin: SequencerAdminStatus
    def __init__(self, connected_participant_uids: _Optional[_Iterable[str]] = ..., sequencer: _Optional[_Union[SequencerHealthStatus, _Mapping]] = ..., domain_id: _Optional[str] = ..., admin: _Optional[_Union[SequencerAdminStatus, _Mapping]] = ...) -> None: ...

class SequencerHealthStatus(_message.Message):
    __slots__ = ("active", "details")
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    active: bool
    details: _wrappers_pb2.StringValue
    def __init__(self, active: bool = ..., details: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class SequencerAdminStatus(_message.Message):
    __slots__ = ("accepts_admin_changes",)
    ACCEPTS_ADMIN_CHANGES_FIELD_NUMBER: _ClassVar[int]
    accepts_admin_changes: bool
    def __init__(self, accepts_admin_changes: bool = ...) -> None: ...

class MediatorNodeStatus(_message.Message):
    __slots__ = ("domain_id",)
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    def __init__(self, domain_id: _Optional[str] = ...) -> None: ...

class SetLogLevelRequest(_message.Message):
    __slots__ = ("level",)
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    level: str
    def __init__(self, level: _Optional[str] = ...) -> None: ...

class SetLogLevelResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLastErrorsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLastErrorsResponse(_message.Message):
    __slots__ = ("errors",)
    class Error(_message.Message):
        __slots__ = ("trace_id", "message")
        TRACE_ID_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        trace_id: str
        message: str
        def __init__(self, trace_id: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    errors: _containers.RepeatedCompositeFieldContainer[GetLastErrorsResponse.Error]
    def __init__(self, errors: _Optional[_Iterable[_Union[GetLastErrorsResponse.Error, _Mapping]]] = ...) -> None: ...

class GetLastErrorTraceRequest(_message.Message):
    __slots__ = ("trace_id",)
    TRACE_ID_FIELD_NUMBER: _ClassVar[int]
    trace_id: str
    def __init__(self, trace_id: _Optional[str] = ...) -> None: ...

class GetLastErrorTraceResponse(_message.Message):
    __slots__ = ("messages",)
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, messages: _Optional[_Iterable[str]] = ...) -> None: ...
